@@ -650,7 +650,7 @@ impl<'a> Expander<'a> {
             }
             syn::Fields::Unnamed(..) => {
                 let fields = calculate_tests(fields.len(), tests);
-                quote!(#encoder_t::encode_tuple(#encoder_var, #fields)?)
+                quote!(#encoder_t::encode_tuple_struct(#encoder_var, #fields)?)
             }
             syn::Fields::Unit => {
                 return quote!(#encoder_t::encode_unit_struct(#encoder_var));
@@ -718,8 +718,20 @@ impl<'a> Expander<'a> {
                 &variant.ident,
             );
 
+            let (encode_function, len) = match &variant.fields {
+                syn::Fields::Named(_) => (
+                    syn::Ident::new("encode_struct_variant", variant.span()),
+                    Some(variant.fields.len()),
+                ),
+                syn::Fields::Unnamed(_) => (
+                    syn::Ident::new("encode_tuple_variant", variant.span()),
+                    Some(variant.fields.len()),
+                ),
+                syn::Fields::Unit => (syn::Ident::new("encode_unit_variant", variant.span()), None),
+            };
+
             encode = quote! {{
-                let mut variant_encoder = #encoder_t::encode_variant(#encoder_var)?;
+                let mut variant_encoder = #encoder_t::#encode_function(#encoder_var, #len)?;
                 let tag_encoder = #pair_encoder_t::first(&mut variant_encoder)?;
                 #encode_t::encode(&#tag, tag_encoder)?;
                 let _ = {
@@ -978,7 +990,7 @@ impl<'a> Expander<'a> {
                 #decoder_t::decode_struct(#decoder_var, #fields_len)?
             },
             FieldKind::Tuple => quote! {
-                #decoder_t::decode_tuple(#decoder_var, #fields_len)?
+                #decoder_t::decode_tuple_struct(#decoder_var, #fields_len)?
             },
         };
 
